# HostPermissions

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**upstream_host** | **str** |  | [optional] 
**app_id** | **str** | Unique identifier | [optional] [readonly] 
**admin_org_id** | **str** | Unique identifier | [optional] [readonly] 
**allowed_list** | [**list[RenderedRule]**](RenderedRule.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


